@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2022 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,17 +31,20 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2022 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
 """ The license for the module """
 
 import time
-import appier
 import hashlib
 import binascii
 
+import appier
+
+from appier_extras import utils
+
 from appier_extras.parts.admin.models import base
 from appier_extras.parts.admin.models import role
 from appier_extras.parts.admin.partials import authenticable
@@ -784,7 +787,14 @@ class Account(base.Base, authenticable.Authenticable):
         cls = self.__class__
         return cls.generate(value)
 
-    def _send_avatar(self, image = "avatar.png", strict = False, cache = False):
+    def _send_avatar(
+        self,
+        image = "avatar.png",
+        width = None,
+        height = None,
+        strict = False,
+        cache = False
+    ):
         admin_part = self.owner.admin_part
         avatar = self.avatar if hasattr(self, "avatar") else None
         if not avatar:
@@ -795,10 +805,17 @@ class Account(base.Base, authenticable.Authenticable):
                 "images/" + image,
                 static_path = admin_part.static_path
             )
-        return self.owner.send_file(
+        resized = bool(width or height)
+        avatar_data, avatar_etag = utils.resize_image(
             avatar.data,
-            content_type = avatar.mime,
             etag = avatar.etag,
+            width = width,
+            height = height
+        ) if resized else (avatar.data, avatar.etag)
+        return self.owner.send_file(
+            avatar_data,
+            content_type = avatar.mime,
+            etag = avatar_etag,
             cache = cache
         )
 
@@ -833,10 +850,12 @@ class Account(base.Base, authenticable.Authenticable):
                 else:
                     if not isinstance(previous, list):
                         previous = [previous]
-                    if not value in previous:
-                        value = previous + [value]
-                    else:
-                        value = previous
+                    if not isinstance(value, list):
+                        value = [value]
+                    for item in value:
+                        if item in previous: continue
+                        previous.append(item)
+                    value = previous
             target[key] = value
         return target
 
@@ -912,8 +931,7 @@ class Account(base.Base, authenticable.Authenticable):
         level = 2
     )
     def impersonate(self):
-        impersonate = appier.conf("ADMIN_IMPERSONATE", False, cast = bool)
-        if not impersonate:
+        if not self.owner.admin_impersonate:
             raise appier.SecurityError(message = "Impersonation is not allowed")
         self._set_account()
 
@@ -965,9 +983,23 @@ class Account(base.Base, authenticable.Authenticable):
         level = 2
     )
     def change_username_s(self, username):
+        # retrieves the global reference to the account class so that
+        # it can be used for the triggering of global operations
+        cls = self.__class__
+
+        # saves the previous username value as it's going to be used
+        # in the event payload once there's a trigger operation
+        username_p = self.username
+
+        # updates the account's username and then saves the instance
+        # so that it reflects the new username
         self.username = username
         self.save()
 
+        # triggers the event that indicates the change in the username
+        # so that any listener can act on it
+        cls.trigger_g("change_username", self, username_p)
+
     @appier.operation(
         name = "Change Email",
         description = """Changing the email of an account is
