@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2022 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2022 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -76,6 +76,15 @@ class LogglyPart(appier.Part):
     def version(self):
         return base.VERSION
 
+    def info(self):
+        info = appier.Part.info(self)
+        info.update(
+            log = self.log,
+            buffer_size = self.buffer_size,
+            timeout = self.timeout
+        )
+        return info
+
     def load(self):
         appier.Part.load(self)
 
