@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2022 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2022 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -336,3 +336,30 @@ class AccountTest(unittest.TestCase):
                 }
             }
         )
+
+        result = account._join_m(
+            {
+                "name" : "brands-origin",
+                "brand" : "nike",
+                "ctx" : {
+                    "brand" : ["nike", "nifty"]
+                }
+            }, {
+                "name" : "brands-target",
+                "brand" : "adidas",
+                "ctx" : {
+                    "brand" : ["adidas", "amidas"]
+                }
+            }
+        )
+
+        self.assertEqual(
+            result,
+            {
+                "name" : ["brands-target", "brands-origin"],
+                "brand" : ["adidas", "nike"],
+                "ctx" : {
+                    "brand" : ["adidas", "amidas", "nike", "nifty"]
+                }
+            }
+        )
