@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2022 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -28,16 +28,18 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2022 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
 """ The license for the module """
 
 from . import format
+from . import image
 from . import markdown
 from . import net
 
 from .format import SafeFormatter
+from .image import resize_image
 from .markdown import MarkdownParser, MarkdownGenerator, MarkdownDebug, MarkdownHTML, has_regex
 from .net import size_round_unit
